from PyQt5.QtWidgets import QWidget, QDesktopWidget
from PyQt5.QtCore import QRect, Qt, QObject, pyqtSignal
from PyQt5.QtGui import QPainter, QColor, QFont

from pqwidgets.PQImage import PQImage
from pqwidgets.PQLabel import PQLabel
from pqwidgets.PQButton import PQButton
from pqpopups.PQPopupDef import modeOS, DirPathDef, enSoundType, enPopupButton, styleSheet

G_POPUP_KEY_INTERVAL = 8
POPUP_KEYPAD_W = 948
POPUP_KEYPAD_H = 400
WIN_W = 1280
WIN_H = 800
nX = 0
nY = 0
KEYSIZE = (52,52)
Rect_1 = QRect(nX + 24, nY + 86, 52, 52)
Rect_Back = QRect(nX + 804, nY + 86, 110, 52)
Rect_2 = QRect(nX + 114, nY + 146, 52, 52)
Rect_3 = QRect(nX + 130, nY + 206, 52, 52)
Rect_LeftCaps = QRect(nX + 26, nY + 266, 124, 52)
Rect_4 = QRect(nX + 158, nY + 266, 52, 52)
Rect_RightCaps = QRect(nX + 758, nY + 266, 156, 52)
Rect_Space = QRect(nX + 204, nY + 326, 530, 52)
ARRAY_NUBER = ['','1','2','3','4','5','6','7','8','9','0','-','='],['','1','2','3','4','5','6','7','8','9','0','_','+']
ARRAY_QWERT = ['Q','W','E','R','T','Y','U','I','O','P','[',']'],['q','w','e','r','t','y','u','i','o','p','{','}']
ARRAY_ASDFG = ['A','S','D','F','G','H','J','K','L','',''],['a','s','d','f','g','h','j','k','l','','']
ARRAY_ZXCVB = ['Z','X','C','V','B','N','M',',','',''],['z','x','c','v','b','n','m',',','','']
LENGTH_NUMBER=13
LENGTH_QWERT=12
LENGTH_ASDFG=11
LENGTH_ZXCVB = 10

# ------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------------------------------------------------------------
# UI UiKeypad
# ------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------------------------------------------------------------

class popupNumberKeypadWidgetSignals(QObject):
    # SIGNALS
    CLOSE = pyqtSignal()


class UiKeypad_widget(QWidget):
    def __init__(self, parent):
        super(UiKeypad_widget, self).__init__(parent)
        self.Variable_Init()
        self.Disp_Background()
        self.Disp_Init()
        self.Disp_Keyboard()
        # self.Disp_CenterWindow()

    def paintEvent(self, event):
        screen = self.size()
        qp = QPainter()
        qp.begin(self)
        qp.setRenderHint(QPainter.Antialiasing, True)
        qp.setPen(self.penColor)
        qp.setBrush(self.fillColor)
        qp.drawRect(0, 0, screen.width(), screen.height())
        qp.end()

        # resize
        x = screen.width() / 2
        y = screen.height() / 2
        keypadX = x - (POPUP_KEYPAD_W / 2)
        keypadY = y - (POPUP_KEYPAD_H / 2)
        self.lbKeyPadBG.move(keypadX, keypadY)
        self.lbKeyPadBG_Edit.move(keypadX + 160, keypadY + 15)
        self.lbKeypadVal.move(keypadX + 175, keypadY + 20)
        self.btnAllClear.move(keypadX + 715, keypadY + 32)
        self.btnClose.move(keypadX + 882, keypadY + 10)
        self.btnDone.move(keypadX + 744, keypadY + 326)
        posX = Rect_1.x() + keypadX
        for i in range(LENGTH_NUMBER):
            self.btnNUMBER[i].move(posX, Rect_1.y() + keypadY)
            posX = posX +60
        posX = Rect_2.x() + keypadX
        for i in range(LENGTH_QWERT):
            self.btnQWERT[i].move(posX, Rect_2.y() + keypadY)
            posX = posX +60
        posX = Rect_3.x() + keypadX
        for i in range(LENGTH_ASDFG):
            self.btnASDFG[i].move(posX, Rect_3.y() + keypadY)
            posX = posX +60
        posX = Rect_4.x() + keypadX
        for i in range(LENGTH_ZXCVB):
            self.btnZXCVB[i].move(posX, Rect_4.y() + keypadY)
            posX = posX +60
        self.btnSpace.move(Rect_Space.x()+keypadX,Rect_Space.y()+keypadY)
        self.btnBackSpace.move(Rect_Back.x() + keypadX, Rect_Back.y() + keypadY)
        self.btnLeftCaps.move(Rect_LeftCaps.x() + keypadX, Rect_LeftCaps.y() + keypadY)
        self.btnRightCaps.move(Rect_RightCaps.x() + keypadX, Rect_RightCaps.y() + keypadY)

    def Variable_Init(self):
        self.btnNUMBER = [PQLabel for i in range(LENGTH_NUMBER)]
        self.btnQWERT = [PQLabel for i in range(LENGTH_QWERT)]
        self.btnASDFG = [PQLabel for i in range(LENGTH_ASDFG)]
        self.btnZXCVB = [PQLabel for i in range(LENGTH_ZXCVB)]

    def Disp_Background(self):
        self.setWindowFlags(Qt.FramelessWindowHint)
        self.setAttribute(Qt.WA_TranslucentBackground)

        self.fillColor = QColor(30, 30, 30, 120)
        self.penColor = QColor("#333333")

        self.SIGNALS = popupNumberKeypadWidgetSignals()

    def Disp_Init(self):
        self.lbKeyPadBG = PQLabel(self, QRect(0, 0, POPUP_KEYPAD_W, POPUP_KEYPAD_H))
        self.lbKeyPadBG.setStyleSheet(styleSheet.BACKGROUND_STYLE_01)

        self.lbKeyPadBG_Edit = PQLabel(self, QRect(0, 0, 600, 60))
        self.lbKeyPadBG_Edit.setStyleSheet(styleSheet.EDIT_STYLE_01)

        self.lbKeypadVal = PQLabel(self, QRect(146 + 10, 15 + 5, 596 - 70, 60 - 15))

        self.btnAllClear = PQLabel(self, QRect(0, 0, 24, 24), "X",18,False)
        # QLabel에 스타일 적용
        self.btnAllClear.setStyleSheet(styleSheet.CIRCLE_STYLE_01)
        self.btnAllClear.move(695, 32)
        self.btnAllClear.clicked.connect(self.onBtnClickKeypadPopupAllClear)

        self.btnClose = PQLabel(self, QRect(0, 0, 50, 50),'X',40,False)
        self.btnClose.setAlignment(Qt.AlignCenter | Qt.AlignVCenter)
        self.btnClose.setStyleSheet(styleSheet.BACKGROUND_STYLE_02)
        # QFont를 사용하여 폰트 변경
        font = QFont('Gothic', 35, QFont.Bold)  # 폰트명, 크기, 굵기 설정
        self.btnClose.setFont(font)
        self.btnClose.move(892, 32)
        self.btnClose.clicked.connect(self.onBtnClickKeypadPopupClose)

        self.btnDone = PQButton(self, QRect(0, 0, 170, 52),'Done',18,False,QColor(109, 209, 207),QColor(69, 179, 176),QColor(255, 255, 255),0)
        self.btnDone.move(744, 326)
        self.btnDone.clicked.connect(self.onBtnClickKeypadDone)

    def Disp_Keyboard(self):
        #NUMPAD
        for item in range(0, LENGTH_NUMBER):
            self.btnNUMBER[item] = PQLabel(self, QRect(0,0,KEYSIZE[0],KEYSIZE[1]),ARRAY_NUBER[0][item],18,False)#,QColor(230, 230, 230),QColor(210, 210, 210),QColor(0, 0, 0),0)
            if item < 11 and item > 0:
                self.btnNUMBER[item].setStyleSheet(styleSheet.KEYBOARD_STYLE_02)
            else:
                self.btnNUMBER[item].setStyleSheet(styleSheet.KEYBOARD_STYLE_01)
            self.btnNUMBER[item].clicked.connect(lambda r=item: self.KeypadInputClicked_Number(r))
        # Q, W, E, R, T, Y, U, I, O, P, [, ]
        for item in range(0, LENGTH_QWERT):
            self.btnQWERT[item] = PQLabel(self, QRect(0,0,KEYSIZE[0],KEYSIZE[1]),ARRAY_QWERT[0][item],18,False)#,QColor(230, 230, 230),QColor(210, 210, 210),QColor(0, 0, 0),0)
            self.btnQWERT[item].setStyleSheet(styleSheet.KEYBOARD_STYLE_01)
            self.btnQWERT[item].clicked.connect(lambda r=item: self.KeypadInputClicked_QWERT(r))
        # A, S, D, F, G, H, J, K, L, ;, '
        for item in range(0, LENGTH_ASDFG):
            self.btnASDFG[item] = PQLabel(self, QRect(0,0,KEYSIZE[0],KEYSIZE[1]),ARRAY_ASDFG[0][item],18,False)#,QColor(230, 230, 230),QColor(210, 210, 210),QColor(0, 0, 0),0)
            self.btnASDFG[item].setStyleSheet(styleSheet.KEYBOARD_STYLE_01)
            self.btnASDFG[item].clicked.connect(lambda r=item: self.KeypadInputClicked_ASDFG(r))
        # Z, X, C, V, B, N, M, (,), (.), /
        for item in range(0, LENGTH_ZXCVB):
            self.btnZXCVB[item] = PQLabel(self, QRect(0,0,KEYSIZE[0],KEYSIZE[1]),ARRAY_ZXCVB[0][item],18,False)#,QColor(230, 230, 230),QColor(210, 210, 210),QColor(0, 0, 0),0)
            self.btnZXCVB[item].setStyleSheet(styleSheet.KEYBOARD_STYLE_01)
            self.btnZXCVB[item].clicked.connect(lambda r=item: self.KeypadInputClicked_ZXCVB(r))
        # Space
        self.btnSpace = PQLabel(self, Rect_Space, '', 18, False)#, QColor(230, 230, 230), QColor(210, 210, 210),QColor(0, 0, 0), 0)
        self.btnSpace.setStyleSheet(styleSheet.KEYBOARD_STYLE_01)
        self.btnSpace.clicked.connect(self.KeypadInputClicked_Space)
        # Backspace
        self.btnBackSpace = PQLabel(self, Rect_Back, 'Back', 18, False)#, QColor(230, 230, 230), QColor(210, 210, 210),QColor(0, 0, 0), 0)
        self.btnBackSpace.setStyleSheet(styleSheet.KEYBOARD_STYLE_01)
        self.btnBackSpace.clicked.connect(self.KeypadInputClicked_Backspace)
        # Left Caps
        self.btnLeftCaps = PQLabel(self, Rect_LeftCaps, 'Shift', 18, False)#, QColor(230, 230, 230), QColor(210, 210, 210),QColor(0, 0, 0), 0)
        self.btnLeftCaps.setStyleSheet(styleSheet.KEYBOARD_STYLE_01)
        self.btnLeftCaps.clicked.connect(self.KeypadInputClicked_Caps)
        # Right Caps
        self.btnRightCaps = PQLabel(self, Rect_RightCaps, 'Shift', 18, False)#, QColor(230, 230, 230), QColor(210, 210, 210),QColor(0, 0, 0), 0)
        self.btnRightCaps.setStyleSheet(styleSheet.KEYBOARD_STYLE_01)
        self.btnRightCaps.clicked.connect(self.KeypadInputClicked_Caps)

    def Disp_CenterWindow(self):
        self.setAttribute(Qt.WA_TranslucentBackground)
        screen = QDesktopWidget().screenGeometry()
        x = (screen.width() - WIN_W) / 2
        y = (screen.height() - WIN_H) / 2

        if modeOS.mode_Curr == modeOS.mode_Windows:
            self.setWindowFlags(self.windowFlags() | Qt.FramelessWindowHint)
            self.setGeometry(x + ((WIN_W - POPUP_KEYPAD_W) / 2), y + ((WIN_H - POPUP_KEYPAD_H) / 2), POPUP_KEYPAD_W,
                             POPUP_KEYPAD_H)
        else:
            self.setWindowFlags(self.windowFlags() | Qt.FramelessWindowHint)
            self.setGeometry(x + ((WIN_W - POPUP_KEYPAD_W) / 2), y + ((WIN_H - POPUP_KEYPAD_H) / 2), POPUP_KEYPAD_W,
                             POPUP_KEYPAD_H)

# ------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------------------------------------------------------------
# popup popupKeypad
# ------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------------------------------------------------------------
class PQPopupKeypad_widget_1280x800(UiKeypad_widget):
    def __init__(self, parent, keyVal=  "", rect = QRect(0,0,WIN_W,WIN_H)):
        super(PQPopupKeypad_widget_1280x800, self).__init__(parent)
        self.parent = parent
        self.result = ""
        self.keyVal = keyVal
        self.bCaps = False
        self.retKey = enPopupButton.Btn_Cancel
        self.lbKeypadVal.setText(self.keyVal)
        self.move(rect.x(),rect.y())
        self.resize(rect.width(),rect.height())

    def KeypadInputClicked_AllClear(self, x, y, rect):
        stX = rect.x()
        stY = rect.y()
        if stX <= x <= stX + rect.width() and stY <= y <= stY + rect.height():
            # _com.ComSound.play(enSoundType.EN_BUTTON_SOUND_TYPE)
            self.lbKeypadVal.setText("")
            return False
        return True

    def KeypadInputClicked_Space(self):
        self.InputValCal(True, ' ')

    def KeypadInputClicked_ZXCVB(self,item):
        if item == 0:
            self.inputCapsKey('Z', 'z')
        elif item == 1:
            self.inputCapsKey('X', 'x')
        elif item == 2:
            self.inputCapsKey('C', 'c')
        elif item == 3:
            self.inputCapsKey('V', 'v')
        elif item == 4:
            self.inputCapsKey('B', 'b')
        elif item == 5:
            self.inputCapsKey('N', 'n')
        elif item == 6:
            self.inputCapsKey('M', 'm')
        elif item == 7:
            self.inputCapsKey(',', '')  # (',', '<')
        elif item == 8:
            self.inputCapsKey('', '')  # ('.', '>')
        elif item == 9:
            self.inputCapsKey('', '')  # ('/', '?')

    def KeypadInputClicked_Caps(self):
        self.setKeypadCaps()

    def KeypadInputClicked_ASDFG(self, item):
        if item == 0:
            self.inputCapsKey('A', 'a')
        elif item == 1:
            self.inputCapsKey('S', 's')
        elif item == 2:
            self.inputCapsKey('D', 'd')
        elif item == 3:
            self.inputCapsKey('F', 'f')
        elif item == 4:
            self.inputCapsKey('G', 'g')
        elif item == 5:
            self.inputCapsKey('H', 'h')
        elif item == 6:
            self.inputCapsKey('J', 'j')
        elif item == 7:
            self.inputCapsKey('K', 'k')
        elif item == 8:
            self.inputCapsKey('L', 'l')
        elif item == 9:
            self.inputCapsKey('', '')  # (';', ':')
        elif item == 10:
            self.inputCapsKey('', '')  # ("'", '"')

    def KeypadInputClicked_QWERT(self, item):
        if item == 0:
            self.inputCapsKey('Q', 'q')
        elif item == 1:
            self.inputCapsKey('W', 'w')
        elif item == 2:
            self.inputCapsKey('E', 'e')
        elif item == 3:
            self.inputCapsKey('R', 'r')
        elif item == 4:
            self.inputCapsKey('T', 't')
        elif item == 5:
            self.inputCapsKey('Y', 'y')
        elif item == 6:
            self.inputCapsKey('U', 'u')
        elif item == 7:
            self.inputCapsKey('I', 'i')
        elif item == 8:
            self.inputCapsKey('O', 'o')
        elif item == 9:
            self.inputCapsKey('P', 'p')
        elif item == 10:
            self.inputCapsKey('[', '{')
        elif item == 11:
            self.inputCapsKey(']', '}')

    def KeypadInputClicked_Backspace(self):
        self.InputValCal(False, "")

    def KeypadInputClicked_Number(self, item):
        if item == 0:
            self.inputCapsKey('', '')  # ('`', '~')
        elif item == 1:
            self.inputCapsKey('1', '1')  # ('1', '!')
        elif item == 2:
            self.inputCapsKey('2', '2')  # ('2', '@')
        elif item == 3:
            self.inputCapsKey('3', '3')  # ('3', '#')
        elif item == 4:
            self.inputCapsKey('4', '4')  # ('4', '$')
        elif item == 5:
            self.inputCapsKey('5', '5')  # ('5', '%')
        elif item == 6:
            self.inputCapsKey('6', '6')  # ('6', '^')
        elif item == 7:
            self.inputCapsKey('7', '7')  # ('7', '&')
        elif item == 8:
            self.inputCapsKey('8', '8')  # ('8', '*')
        elif item == 9:
            self.inputCapsKey('9', '9')  # ('9', '(')
        elif item == 10:
            self.inputCapsKey('0', '0')  # ('0', ')')
        elif item == 11:
            self.inputCapsKey('-', '_')
        elif item == 12:
            self.inputCapsKey('=', '+')

    def setKeypadCaps(self):
        self.bCaps = not self.bCaps
        if self.bCaps:
            self.ChangeCapsKeyboard(1)
        else:
            self.ChangeCapsKeyboard(0)

    def InputValCal(self, Add, Val):
        strVal = self.lbKeypadVal.text()
        if Add == True:
            strText = strVal + Val
            self.lbKeypadVal.setText(strText)
        else:  # Substrction
            nLen = len(strVal)
            if nLen > 0:
                strText = strVal[:nLen - 1]
                self.lbKeypadVal.setText(strText)

    def GetValue(self):
        self.result = self.lbKeypadVal.text()
        return self.retKey, self.result

    def inputCapsKey(self, caps, nocaps):
        if not self.bCaps:
            self.InputValCal(True, caps)
        else:
            self.InputValCal(True, nocaps)

    def ChangeCapsKeyboard(self,Caps):
        #NUMPAD
        for item in range(0, 13):
            self.btnNUMBER[item].setText(ARRAY_NUBER[Caps][item])
        # Q, W, E, R, T, Y, U, I, O, P, [, ]
        for item in range(0, 12):
            self.btnQWERT[item].setText(ARRAY_QWERT[Caps][item])
        # A, S, D, F, G, H, J, K, L, ;, '
        for item in range(0, 11):
            self.btnASDFG[item].setText(ARRAY_ASDFG[Caps][item])
        # Z, X, C, V, B, N, M, (,), (.), /
        for item in range(0, 10):
            self.btnZXCVB[item].setText(ARRAY_ZXCVB[Caps][item])

    # ------------------------------------------------------------------------------------------------------------------------
    # Button Event
    # ------------------------------------------------------------------------------------------------------------------------
    def onBtnClickKeypadPopupClose(self):
        # _com.ComSound.play(enSoundType.EN_BUTTON_SOUND_TYPE)
        self.retKey = enPopupButton.Btn_Cancel
        self.SIGNALS.CLOSE.emit()

    def onBtnClickKeypadDone(self):
        # _com.ComSound.play(enSoundType.EN_BUTTON_SOUND_TYPE)
        self.retKey = enPopupButton.Btn_Ok
        self.SIGNALS.CLOSE.emit()

    def onBtnClickKeypadPopupAllClear(self):
        # _com.ComSound.play(enSoundType.EN_BUTTON_SOUND_TYPE)
        self.lbKeypadVal.setText("")




from PyQt5.QtWidgets import QWidget, QDesktopWidget
from PyQt5.QtCore import QRect, Qt, QObject, pyqtSignal
from PyQt5.QtGui import QPainter, QColor, QFont

from pqwidgets.PQImage import PQImage
from pqwidgets.PQLabel import PQLabel
from pqwidgets.PQButton import PQButton
from pqpopups.PQPopupDef import modeOS, DirPathDef, enSoundType, enPopupButton, styleSheet, enNumpadMode

WIN_W = 1280
WIN_H = 800
KEYSIZE = (52,52)
Rect_1 = QRect(24, 146, 52, 52)
Rect_0_key = QRect(24, 326, 52, 52)
Rect_Back = QRect(24 + 8 + 52, 326, 52, 52)
Rect_OK = QRect(84 + 8 + 52, 326, 52, 52)
POPUP_NUMKEYPAD_W = 220
POPUP_NUMKEYPAD_H = 400
ARRAY_NUBER = ['1','2','3','4','5','6','7','8','9']

class popupNumberKeypadWidgetSignals(QObject):
    # SIGNALS
    CLOSE = pyqtSignal()

class PQPopupNumpad_simple_widget_1280x800(QWidget):
    def __init__(self, parent, maxlen, mode=enNumpadMode.EN_MODE_NONE, rect = QRect(0,0,WIN_W,WIN_H)):
        super(PQPopupNumpad_simple_widget_1280x800, self).__init__(parent)
        self.parent = parent
        self.result = ""
        self.maxLen = maxlen
        self.retKey = enPopupButton.Btn_Cancel
        self.move(rect.x(),rect.y())
        self.resize(rect.width(),rect.height())
        # 기본, 시간, 온도, 스피드, 볼륨 (스피드, 볼륨은 입력값이 최대값 이상일 경우 최대값으로 리턴하기 위함)
        self.numMode = mode


        #self.Disp_CenterWindow()
        self.Disp_Background()
        self.Disp_Init()

        # 시간, 온도값 입력 시 입력 데이터가 기본 데이터(00:00 or 00.00)를 대체 하기 위함
        if self.numMode == enNumpadMode.EN_MODE_TIME or self.numMode == enNumpadMode.EN_MODE_TEMP:
            self.Disp_Underscore()
            self.insertPos = 0
            self.setUnderscore(self.insertPos)

    def paintEvent(self, event):
        screen = self.size()
        qp = QPainter()
        qp.begin(self)
        qp.setRenderHint(QPainter.Antialiasing, True)
        qp.setPen(self.penColor)
        qp.setBrush(self.fillColor)
        qp.drawRect(0, 0, screen.width(), screen.height())
        qp.end()

        # resize
        x = screen.width() / 2
        y = screen.height() / 2
        keypadX = x - (POPUP_NUMKEYPAD_W / 2)
        keypadY = y - (POPUP_NUMKEYPAD_H / 2)
        self.lbKeyPadBG.move(keypadX, keypadY)
        self.lbKeyPadBG_Edit.move(keypadX+26, keypadY+64)
        self.lbKeypadVal.move(keypadX + 28, keypadY + 64)
        self.btnClose.move(keypadX + 172, keypadY + 22)
        posX = Rect_1.x() + keypadX
        posY = Rect_1.y() + keypadY
        for i in range(3):
            for j in range(3):
                self.btnNUMBER[i * 3 + j].move(posX, posY)
                posX = posX +60
            posX = Rect_1.x() + keypadX
            posY = posY +60
        self.btn0Key.move(Rect_0_key.x() + keypadX, Rect_0_key.y() + keypadY)
        self.btnBack.move(Rect_Back.x() + keypadX, Rect_Back.y() + keypadY)
        self.btnOK.move(Rect_OK.x() + keypadX, Rect_OK.y() + keypadY)

        # 입력 위치 표시 _ (Time, Temperature 용)
        if self.numMode == enNumpadMode.EN_MODE_TIME or self.numMode == enNumpadMode.EN_MODE_TEMP:
            if self.numMode == enNumpadMode.EN_MODE_TIME:
                nX, nY = 75, 120
            elif self.numMode == enNumpadMode.EN_MODE_TEMP:
                nX, nY = 83, 120

            for i in range(int(len(self.lbUnderscore))):
                if i == 2:
                    nX += 7
                self.lbUnderscore[i].move(keypadX + nX, keypadY + nY)
                nX += 16


    def Disp_Background(self):
        self.setWindowFlags(Qt.FramelessWindowHint)
        self.setAttribute(Qt.WA_TranslucentBackground)

        self.fillColor = QColor(30, 30, 30, 120)
        self.penColor = QColor("#333333")

        self.SIGNALS = popupNumberKeypadWidgetSignals()

    def Disp_CenterWindow(self):
        screen = QDesktopWidget().screenGeometry()
        x = (screen.width() - WIN_W) / 2
        y = (screen.height() - WIN_H) / 2

        if modeOS.mode_Curr == modeOS.mode_Windows:
            self.setWindowFlags(self.windowFlags() | Qt.FramelessWindowHint)
            self.setGeometry(x + ((WIN_W - POPUP_NUMKEYPAD_W) / 2), y + ((WIN_H - POPUP_NUMKEYPAD_H) / 2), POPUP_NUMKEYPAD_W, POPUP_NUMKEYPAD_H)
        else:
            self.setWindowFlags(self.windowFlags() | Qt.FramelessWindowHint)
            self.setGeometry(x + ((WIN_W - POPUP_NUMKEYPAD_W) / 2), y + ((WIN_H - POPUP_NUMKEYPAD_H) / 2), POPUP_NUMKEYPAD_W, POPUP_NUMKEYPAD_H)

    def Disp_Init(self):
        self.lbKeyPadBG = PQLabel(self, QRect(0, 0, POPUP_NUMKEYPAD_W, POPUP_NUMKEYPAD_H))
        self.lbKeyPadBG.setStyleSheet(styleSheet.BACKGROUND_STYLE_01)

        self.lbKeyPadBG_Edit = PQLabel(self, QRect(0, 0, 170, 60))
        self.lbKeyPadBG_Edit.setStyleSheet(styleSheet.EDIT_STYLE_01)

        self.btnNUMBER = [PQLabel for i in range(len(ARRAY_NUBER))]
        for item in range(0, len(ARRAY_NUBER)):
            self.btnNUMBER[item] = PQLabel(self, QRect(0, 0, KEYSIZE[0], KEYSIZE[1]), ARRAY_NUBER[item], 18, False)
            self.btnNUMBER[item].setStyleSheet(styleSheet.KEYBOARD_STYLE_02)
            self.btnNUMBER[item].clicked.connect(lambda r=item + 1: self.KeypadInputClicked_Number(r))

        self.btn0Key = PQLabel(self, QRect(0, 0, KEYSIZE[0], KEYSIZE[1]), "0", 18, False)
        self.btn0Key.setStyleSheet(styleSheet.KEYBOARD_STYLE_02)
        self.btn0Key.clicked.connect(lambda : self.KeypadInputClicked_Number(0))

        self.btnBack = PQLabel(self, QRect(0, 0, KEYSIZE[0], KEYSIZE[1]), "←", 18, True)
        self.btnBack.setStyleSheet(styleSheet.KEYBOARD_STYLE_01)
        self.btnBack.clicked.connect(self.KeypadInputClicked_Back)

        self.btnOK = PQLabel(self, QRect(0, 0, KEYSIZE[0], KEYSIZE[1]), "OK", 18, False)
        self.btnOK.setStyleSheet(styleSheet.KEYBOARD_STYLE_01)
        self.btnOK.clicked.connect( self.KeypadInputClicked_OK)

        if self.numMode == enNumpadMode.EN_MODE_NONE or self.numMode == enNumpadMode.EN_MODE_SPEED or \
                self.numMode == enNumpadMode.EN_MODE_VOLUME or self.numMode == enNumpadMode.EN_MODE_COLLECT or \
                self.numMode == enNumpadMode.EN_MODE_CYCLE:
            self.lbKeypadVal = PQLabel(self, QRect(26, 74, 168, 56), "", 20)
        elif self.numMode == enNumpadMode.EN_MODE_TIME:
            self.lbKeypadVal = PQLabel(self, QRect(26, 74, 168, 56), "00:00", 20)
        elif self.numMode == enNumpadMode.EN_MODE_TEMP:
            self.lbKeypadVal = PQLabel(self, QRect(26, 74, 168, 56),"00.0", 20)

        self.btnClose = PQLabel(self,QRect(0, 0, 24, 24),'X',18)
        self.btnClose.setStyleSheet(styleSheet.BACKGROUND_STYLE_02)
        self.btnClose.move(172, 32)
        self.btnClose.clicked.connect(self.onBtnClickKeypadPopupClose)

    # 입력 위치 표시 _ (Time, Temperature 용)
    def Disp_Underscore(self):
        self.lbUnderscore = [PQLabel, PQLabel, PQLabel, PQLabel]

        if self.numMode == enNumpadMode.EN_MODE_TIME:
            nX, nY = 75, 120
        elif self.numMode == enNumpadMode.EN_MODE_TEMP:
            nX, nY = 83, 120

        nW, nH = 14, 5
        for i in range(int(len(self.lbUnderscore))):
            if i == 2:
                nX += 7
            self.lbUnderscore[i] = PQLabel(self, QRect(nX, nY, nW, nH))
            self.lbUnderscore[i].setVisible(False)
            nX += 16

    def KeypadInputClicked_Back(self):
        self.InputValCal(False, "")


    def KeypadInputClicked_OK(self):
        self.retKey = enPopupButton.Btn_Ok
        self.SIGNALS.CLOSE.emit()

    def KeypadInputClicked_Number(self, item):
        strTemp = self.lbKeypadVal.text()
        nLen = len(strTemp)

        if self.numMode == enNumpadMode.EN_MODE_NONE or self.numMode == enNumpadMode.EN_MODE_SPEED or \
                self.numMode == enNumpadMode.EN_MODE_VOLUME or self.numMode == enNumpadMode.EN_MODE_COLLECT or \
                self.numMode == enNumpadMode.EN_MODE_CYCLE:
            if nLen >= self.maxLen:      return
        self.InputValCal(True, str(item))

    def InputValCal(self, Add, Val):
        strVal = self.lbKeypadVal.text()
        if self.numMode == enNumpadMode.EN_MODE_NONE or self.numMode == enNumpadMode.EN_MODE_SPEED or \
                self.numMode == enNumpadMode.EN_MODE_VOLUME or self.numMode == enNumpadMode.EN_MODE_COLLECT or \
                self.numMode == enNumpadMode.EN_MODE_CYCLE:
            if Add == True:
                strText = strVal + Val
                self.lbKeypadVal.setText(strText)
            else: #Substrction
                nLen = len(strVal)
                if nLen > 0:
                    strText = strVal[:nLen - 1]
                    self.lbKeypadVal.setText(strText)
        else:   # Time, Temperature 처리
            if Add == True:
                #10분 단위, 10초 단위가 6이상일 겨우 처리 입력 제한
                if self.numMode == enNumpadMode.EN_MODE_TIME and int(Val) > 5 and (self.insertPos == 0 or self.insertPos == 2):
                    return

                # ':' or '.' 값 때문에 앞 2자리와 뒷 자리 처리 방법을 달리 함
                if self.insertPos < 2:
                    strText = strVal[:self.insertPos] + Val + strVal[self.insertPos + 1:]
                    self.lbKeypadVal.setText(strText)
                else:
                    strText = strVal[:self.insertPos + 1] + Val + strVal[self.insertPos + 2:]
                    self.lbKeypadVal.setText(strText)

                # 길이 초과 시 입력 제한
                if self.numMode == enNumpadMode.EN_MODE_TIME:
                    if self.insertPos < 3:
                        self.insertPos += 1
                elif self.numMode == enNumpadMode.EN_MODE_TEMP:
                    if self.insertPos < 2:
                        self.insertPos += 1

            else:
                # ':' or '.' 값 때문에 앞 2자리와 뒷 자리 처리 방법을 달리 함
                if self.insertPos < 2:
                    strText = strVal[:self.insertPos] + "0" + strVal[self.insertPos + 1:]
                    self.lbKeypadVal.setText(strText)
                else:
                    strText = strVal[:self.insertPos + 1] + "0" + strVal[self.insertPos + 2:]
                    self.lbKeypadVal.setText(strText)

                # 첫번째 자리 처리
                if self.insertPos > 0:
                    self.insertPos -= 1

            self.setUnderscore(self.insertPos)

    def setUnderscore(self, pos):
        for i in range(int(len(self.lbUnderscore))):
            self.lbUnderscore[i].setVisible(False)

        self.lbUnderscore[pos].setVisible(True)

    def GetValue(self):
        self.result = self.lbKeypadVal.text()

        if len(self.result) > 0:    # 값 미입력 시 result 변수 int 반환 에러 관련 처리
            # 온도 80도 이상 입력 시 80도로 고정
            if self.numMode == enNumpadMode.EN_MODE_TEMP:
                if int(self.result[:2]) <= 45:
                    self.result = "45.0"

            # 스피드 200 이상 입력 시 200으로 고정
            if self.numMode == enNumpadMode.EN_MODE_SPEED:
                if int(self.result) >= 200:
                    self.result = "200"

            if self.numMode == enNumpadMode.EN_MODE_VOLUME:
                if int(self.result) >= 1000:
                    self.result = "1000"

            if self.numMode == enNumpadMode.EN_MODE_CYCLE:
                if int(self.result) >= 5:
                    self.result = "5"

        return self.retKey, self.result

    # ------------------------------------------------------------------------------------------------------------------------
    # Button Event
    # ------------------------------------------------------------------------------------------------------------------------
    def onBtnClickKeypadPopupClose(self):
        self.retKey = enPopupButton.Btn_Cancel
        self.SIGNALS.CLOSE.emit()





import textwrap

from PyQt5.QtWidgets import QWidget, QDesktopWidget
from PyQt5.QtCore import QRect, Qt, QObject, pyqtSignal
from PyQt5.QtGui import QPainter, QColor

from pqwidgets.PQImage import PQImage
from pqwidgets.PQLabel import PQLabel
from pqwidgets.PQButton import PQButton
from pqpopups.PQPopupDef import modeOS, DirPathDef, enSoundType, enPopupButton, styleSheet, enPopupIcon

WIN_W = 1280
WIN_H = 800
POPUP_MESSAGE_W = 640
POPUP_MESSAGE_H = 300
POPUP_MESSAGE_H_430 = 430

class popupMessageWidgetSignals(QObject):
    # SIGNALS
    CLOSE = pyqtSignal()

class PQPopupMessage_widget_1280x800(QWidget):
    def __init__(self, parent, sMsg = "",msgType = enPopupIcon.Icon_Working,  btnType = enPopupButton.Btn_Ok, rect = QRect(0,0,WIN_W,WIN_H)):
        super(PQPopupMessage_widget_1280x800, self).__init__(parent)
        self.parent = parent
        self.msgType = msgType      #    Icon_Check = 0    Icon_Question = 1    Icon_Warning = 2    Icon_Working = 3
        self.strMsg = sMsg
        self.BtnType = btnType      #    Btn_None = 0    Btn_Ok = 1    Btn_Cancel = 2    Btn_OkCancel = 10    Btn_YesNo = 30
        self.retKey = enPopupButton.Btn_Cancel
        self.move(rect.x(),rect.y())
        self.resize(rect.width(),rect.height())

        self.Disp_Background()
        self.Disp_Init()
        self.BtnDisp_show(self.BtnType)

    def paintEvent(self, event):
        screen = self.size()
        qp = QPainter()
        qp.begin(self)
        qp.setRenderHint(QPainter.Antialiasing, True)
        qp.setPen(self.penColor)
        qp.setBrush(self.fillColor)
        qp.drawRect(0, 0, screen.width(), screen.height())
        qp.end()

        # resize
        x = screen.width() / 2
        y = screen.height() / 2
        popupX = x - (POPUP_MESSAGE_W / 2)
        popupY = y - (POPUP_MESSAGE_H / 2)
        self.lbPopupBG.move(popupX, popupY)
        self.lbPopupBG_OutSymbol.move(popupX+270, popupY-48)
        self.lbPopupBG_InSymbol.move(popupX+280, popupY-38)
        if self.msgType == enPopupIcon.Icon_Working:
            self.lbPopupBG_InSymbolKeyPad.move(popupX+293, popupY-14)
            self.lbPopupBG_InSymbolLine.move(popupX+319, popupY-28)
            posx = popupX+297
            for item in range(0, 7):
                self.lbPopupBG_InSymbolKeyPad1Line[item].move(posx, popupY-8)
                posx = posx + 7
            posx = popupX + 300
            for item in range(0, 6):
                self.lbPopupBG_InSymbolKeyPad2Line[item].move(posx, popupY)
                posx = posx + 7
            posx = popupX + 297
            for item in range(0, 3):
                self.lbPopupBG_InSymbolKeyPad3Line[item].move(posx, popupY+8)
                if item == 1:
                    posx = posx + 36
                else:
                    posx = posx + 6
        elif self.msgType == enPopupIcon.Icon_Check:
            self.lbPopupBG_InSymbol_Sub.move(popupX+300, popupY-22)
        self.lbPopupMsg.move(popupX, popupY-15)
        self.BtnDispMove()

    def Variable_Init(self):
        self.DefaultFont = enFontInfo.DEF_FONT
        self.DefaultFont.setBold(True)

    def Disp_Background(self):
        self.setWindowFlags(Qt.FramelessWindowHint)
        self.setAttribute(Qt.WA_TranslucentBackground)

        self.fillColor = QColor(30, 30, 30, 120)
        self.penColor = QColor("#333333")

        self.SIGNALS = popupMessageWidgetSignals()

    def Disp_CenterWindow(self):
        self.setAttribute(Qt.WA_TranslucentBackground)
        screen = QDesktopWidget().screenGeometry()
        x = (screen.width() - CommonDef.Win_W) / 2
        y = (screen.height() - CommonDef.Win_H) / 2

        if modeOS.mode_Curr == modeOS.mode_Windows:
            self.setWindowFlags(self.windowFlags() | Qt.FramelessWindowHint)
            self.setGeometry(x + ((CommonDef.Win_W - POPUP_MESSAGE_W) / 2), y + ((CommonDef.Win_H - POPUP_MESSAGE_H) / 2), CommonDef.popup_Prog_W, POPUP_MESSAGE_H)
        else:
            self.setWindowFlags(self.windowFlags() | Qt.FramelessWindowHint)
            self.setGeometry(x + ((CommonDef.Win_W - POPUP_MESSAGE_W) / 2), y + ((CommonDef.Win_H - POPUP_MESSAGE_H) / 2), CommonDef.popup_Prog_W, POPUP_MESSAGE_H)

    def Disp_Init(self):
        self.lbPopupBG = PQLabel(self, QRect(0, 0, POPUP_MESSAGE_W, POPUP_MESSAGE_H))
        self.lbPopupBG.setStyleSheet(styleSheet.BACKGROUND_STYLE_03_RADIUS)
        self.lbPopupBG_OutSymbol = PQLabel(self, QRect(0, 0, 100, 100),styleSheet= "background-color:#F7F8F8;border-radius: 50px;")
        if self.msgType == enPopupIcon.Icon_Check:
            self.lbPopupBG_InSymbol = PQLabel(self, QRect(0, 0, 80, 80), text="V", fontSize=40, fontBold=True,styleSheet="color:white;background-color:#009844;border-radius: 40px;")
            self.lbPopupBG_InSymbol_Sub = PQLabel(self, QRect(0, 0, 20, 20), text="", fontSize=40, fontBold=True,styleSheet="color:white;background-color:#009844;border-radius: 40px;")
        elif self.msgType == enPopupIcon.Icon_Warning:
            self.lbPopupBG_InSymbol = PQLabel(self, QRect(0, 0, 80, 80), text="!", fontSize=40, fontBold=True,styleSheet="color:white;background-color:#FC0054;border-radius: 40px;")
        elif self.msgType == enPopupIcon.Icon_Question:
                self.lbPopupBG_InSymbol = PQLabel(self, QRect(0, 0, 80, 80),text="?",fontSize= 40, fontBold = True , styleSheet= "color:white;background-color:#FBB03B;border-radius: 40px;")
        elif self.msgType == enPopupIcon.Icon_Working:
            self.lbPopupBG_InSymbol = PQLabel(self, QRect(0, 0, 80, 80), text="", fontSize=40, fontBold=True,styleSheet="color:white;background-color:#32B7E0;border-radius: 40px;")
            self.lbPopupBG_InSymbolKeyPad = PQLabel(self, QRect(0, 0, 56, 34),styleSheet="color:#32B7E0;background-color:white;border-radius: 8px;")
            self.lbPopupBG_InSymbolLine = PQLabel(self, QRect(0, 0, 3, 15),styleSheet="color:#32B7E0;background-color:white;border-radius: 2px;")
            self.lbPopupBG_InSymbolKeyPad1Line = [PQLabel for i in range(7)]
            self.lbPopupBG_InSymbolKeyPad2Line = [PQLabel for i in range(6)]
            self.lbPopupBG_InSymbolKeyPad3Line = [PQLabel for i in range(3)]
            for item in range(0, 7):
                self.lbPopupBG_InSymbolKeyPad1Line[item] = PQLabel(self, QRect(0, 0, 5, 5),styleSheet="color:#32B7E0;background-color:#32B7E0;border-radius: 2px;")
            for item in range(0, 6):
                self.lbPopupBG_InSymbolKeyPad2Line[item] = PQLabel(self, QRect(0, 0, 5, 5),styleSheet="color:#32B7E0;background-color:#32B7E0;border-radius: 2px;")
            for item in range(0, 3):
                if item == 1:
                    self.lbPopupBG_InSymbolKeyPad3Line[item] = PQLabel(self, QRect(0, 0, 35, 5),styleSheet="color:#32B7E0;background-color:#32B7E0;border-radius: 2px;")
                else:
                    self.lbPopupBG_InSymbolKeyPad3Line[item] = PQLabel(self, QRect(0, 0, 5, 5),styleSheet="color:#32B7E0;background-color:#32B7E0;border-radius: 2px;")
        
        self.lbPopupMsg = PQLabel(self, QRect(0, 0, POPUP_MESSAGE_W, POPUP_MESSAGE_H),self.getMsgTextWrap(self.strMsg))

        self.btnX, self.btnY, self.btnW, self.btnH = 356, 390, 150, 50
        self.btnOk = PQButton(self, QRect(0, 0, self.btnW, self.btnH),fontBold = True,ColorNormal= QColor(29, 49, 75) , ColorPress= QColor(38, 97, 145), ColorText = QColor(255, 255, 255), radius= 25)
        self.btnOk.move(self.btnX, self.btnY)
        self.btnOk.clicked.connect(self.onBtnClickedOk)

        self.btnX, self.btnY = 518, 390
        self.btnCancel = PQButton(self, QRect(0, 0, self.btnW, self.btnH),fontBold = True,ColorNormal= QColor(29, 49, 75) , ColorPress= QColor(38, 97, 145), ColorText = QColor(255, 255, 255), radius= 25)
        self.btnCancel.move(self.btnX, self.btnY)
        self.btnCancel.clicked.connect(self.onBtnClickedCancel)

    def BtnDisp_show(self, btnType):
        self.BtnType = btnType
        self.btnOk.hide()
        self.btnCancel.hide()

        if self.BtnType == enPopupButton.Btn_Ok:
            self.btnOk.setText("OK")
            self.btnOk.show()
        elif self.BtnType == enPopupButton.Btn_Cancel:
            self.btnCancel.setText("CANCEL")
            self.btnCancel.show()
        elif self.BtnType == enPopupButton.Btn_OkCancel:
            self.btnOk.setText("OK")
            self.btnCancel.setText("CANCEL")
            self.btnOk.show()
            self.btnCancel.show()
        elif self.BtnType == enPopupButton.Btn_YesNo:
            self.btnOk.setText("YES")
            self.btnCancel.setText("NO")
            self.btnOk.show()
            self.btnCancel.show()

    def BtnDispMove(self):
        if self.BtnType == enPopupButton.Btn_Ok or self.BtnType == enPopupButton.Btn_Cancel:
            self.btnCancel.move(565, 480)
            self.btnOk.move(565, 480)

        elif self.BtnType == enPopupButton.Btn_OkCancel or self.BtnType == enPopupButton.Btn_YesNo:
            self.btnOk.move(484, 480)
            self.btnCancel.move(646, 480)

    def setMsgText(self, sMsg):
        self.strMsg = self.getMsgTextWrap(sMsg)
        self.lbPopupMsg.setText(self.strMsg)

    def GetValue(self):
        return self.retKey

    def onBtnClickedOk(self):
        self.retKey = enPopupButton.Btn_Ok
        self.SIGNALS.CLOSE.emit()

    def onBtnClickedCancel(self):
        self.retKey = enPopupButton.Btn_Cancel
        self.SIGNALS.CLOSE.emit()

    # 자동 줄바꿈 함수 (언어별 wrapWidth 값 조절이 관건인데...)
    def getMsgTextWrap(self,sMsg, wVal=0):
        if sMsg == "":
            return ""
        else:
            if int(wVal) <= 0:
                isKOR = 0
                isJAP = 0
                for c in sMsg:
                    if ord('\uAC00') <= ord(c) <= ord('\uD7A3'):    # AC00..D7A3  Hangul Syllables  한글
                        isKOR += 1
                    elif ord('\u3040') <= ord(c) <= ord('\u30FF'):  # 3040..309F  Hiragana  일본어 히라가나, 30A0..30FF  Katakana  일본어 카타카나
                        isJAP += 1

                if isKOR == 0 and isJAP == 0:
                    wrapWidth = 30
                else:
                    wrapWidth = 20
            else:
                wrapWidth = wVal
            strMsg = textwrap.wrap(sMsg, width=wrapWidth)
            return '\n'.join(strMsg)


from setuptools import setup, find_packages

setup(
    name='pqpopups',
    version='1.0.5',
    description='A custom PyQt5 popups package',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='kwonyoungil',
    author_email='kwen232@gmail.com',
    url='https://github.com/kyi1107/pqpopups',
    packages=find_packages(),
    install_requires=[
        'PyQt5>=5.15.0',
        'pqwidgets>=1.0.7',
    ],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)



from .PQPopupKeypad_widget_1280x800 import PQPopupKeypad_widget_1280x800
from .PQPopupNumpad_simple_widget_1280x800 import PQPopupNumpad_simple_widget_1280x800
from .PQPopupNumpad_widget_1280x800 import PQPopupNumpad_widget_1280x800
from .PQPopupMessage_widget_1280x800 import PQPopupMessage_widget_1280x800